@@ -16,12 +16,10 @@ def import_api_module(module_path: str):
     """
     base_dir = str(pathlib.Path(__file__).resolve().parent.parent)
     path = str(pathlib.Path(base_dir, *module_path.split(".")))
+    dir_len = len(list(pathlib.Path(base_dir).parts))
     for py_path in glob(str(pathlib.Path(path, '**', '*.py')), recursive=True):
-        py = (
-            (".".join(py_path.split(base_dir)[1:]))
-            .replace(".py", "")
-            .replace("/", ".")[1:]
-        )
+        py = '.'.join(list(pathlib.Path(py_path).parts)[dir_len:])
+        py = py.replace('.py', "")
         mod = __import__(
             py,
         )
@@ -30,3 +28,4 @@ def import_api_module(module_path: str):
         ]
         for cls in classes:
             setattr(sys.modules[module_path], cls.__name__, cls)
+
