@@ -2,17 +2,18 @@
 # @Time : 2024/5/16 10:14
 # @Author : PinBar
 # @File : decorator.py
-from typing import Type
 
 from fastapi.routing import *
 
 from auth.base_authentication import BaseAuthentication
 from auth.base_permission import BasePermission
+from config.settings import CREATE_DEPENDS_SESSION
 
 
 def api_description(
         authentication_classes: List[Type[BaseAuthentication]] = None,
         permission_classes: List[Type[BasePermission]] = None,
+        depend_session: bool = CREATE_DEPENDS_SESSION,
         response_model: Any = Default(None),
         status_code: Optional[int] = None,
         tags: Optional[List[Union[str, Enum]]] = None,
@@ -66,7 +67,10 @@ def api_description(
             ('openapi_extra', openapi_extra),
             ('generate_unique_id_function', generate_unique_id_function),
         ]
-        params = {"permission_classes": permission_classes, "authentication_classes": authentication_classes}
+        params = {"permission_classes": permission_classes,
+                  "authentication_classes": authentication_classes,
+                  "depend_session": depend_session
+                  }
         for field, value in names:
             if value:
                 params[field] = value
